==> kmess-1.3.tar.gz: kmess-1.3/kmess/kmessdebug.h <==
/***************************************************************************
                          kmessdebug.h  -  description
                             -------------------
    begin                : Sun Jan 5 2003
    copyright            : (C) 2003 by Mike K. Bennett
    email                : mkb137b@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KMESSDEBUG_H
#define KMESSDEBUG_H

#ifdef HAVE_CONFIG_H
 #include "config.h"
#endif

#if ( KMESS_DEBUG == 1)

  #define KMESSTEST

/*
  #define KMESSDEBUG_KMESS
  #define KMESSDEBUG_KMESSINTERFACE
  #define KMESSDEBUG_KMESSVIEW
  #define KMESSDEBUG_KMESSVIEWINTERFACE
  #define KMESSDEBUG_INITIALVIEW
  #define KMESSDEBUG_CONNECTION
*/
  #define KMESSDEBUG_NOTIFICATION
  #define KMESSDEBUG_SWITCHBOARD
  #define KMESSDEBUG_SERVERMESSAGES
  #define KMESSDEBUG_SSLLOGINHANDLER
/*

  #define KMESSDEBUG_ACCOUNT
  
  #define KMESSDEBUG_CURRENTACCOUNT
  #define KMESSDEBUG_CONTACT
  #define KMESSDEBUG_CONTACTEXTENSION
  #define KMESSDEBUG_CONTACTLIST
  #define KMESSDEBUG_GROUP
  #define KMESSDEBUG_GROUPLIST
  #define KMESSDEBUG_SETTINGSDIALOG
  #define KMESSDEBUG_CHATMASTER
  #define KMESSDEBUG_CHATWINDOW
  #define KMESSDEBUG_CHATVIEW
  #define KMESSDEBUG_CONTACTSIDEBAR
  #define KMESSDEBUG_CONTACTFRAME
  #define KMESSDEBUG_CONTACTACTION
  #define KMESSDEBUG_IDLETIMER
  #define KMESSDEBUG_POPUPNOTIFICATION
  #define KMESSDEBUG_CONTACTOFFLINENOTIFICATION
  #define KMESSDEBUG_CONTACTONLINENOTIFICATION
  #define KMESSDEBUG_EMAILNOTIFICATION
  #define KMESSDEBUG_CHATNOTIFICATION

  #define KMESSDEBUG_APPLICATION
  #define KMESSDEBUG_TRANSFERFILE
  #define KMESSDEBUG_RECEIVEFILE
  #define KMESSDEBUG_SENDFILE
  #define KMESSDEBUG_IPDIALOG
  #define KMESSDEBUG_TRANSFERPROGRESS
  #define KMESSDEBUG_KDEREMOTEDESKTOP
  #define KMESSDEBUG_REMOTEDESKTOP

  #define KMESSDEBUG_CONTACTPROPERTIES
*/
#endif

#endif

==> kmess-1.4.2.tar.gz: kmess-1.4.2/kmess/kmessdebug.h <==
/***************************************************************************
                          kmessdebug.h  -  description
                             -------------------
    begin                : Sun Jan 5 2003
    copyright            : (C) 2003 by Mike K. Bennett
    email                : mkb137b@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KMESSDEBUG_H
#define KMESSDEBUG_H

#ifdef HAVE_CONFIG_H
 #include "config.h"
#endif

#if ( KMESS_DEBUG == 1)

  #define KMESSTEST

  #define KMESS_NETWORK_WINDOW


  #define KMESSDEBUG_KMESS
  #define KMESSDEBUG_KMESSINTERFACE
  #define KMESSDEBUG_KMESSVIEW
  #define KMESSDEBUG_KMESSVIEWINTERFACE
  #define KMESSDEBUG_KMESSLISTVIEWITEM
  #define KMESSDEBUG_CONTACTLISTVIEWITEM
  #define KMESSDEBUG_GROUPLISTVIEWITEM
  #define KMESSDEBUG_INITIALVIEW
  #define KMESSDEBUG_CONNECTION

  #define KMESSDEBUG_NOTIFICATION
  #define KMESSDEBUG_SWITCHBOARD
  #define KMESSDEBUG_SERVERMESSAGES
  #define KMESSDEBUG_SSLLOGINHANDLER
  #define KMESSDEBUG_MSNFTP


  #define KMESSDEBUG_ACCOUNT
  
  #define KMESSDEBUG_CURRENTACCOUNT
  #define KMESSDEBUG_CONTACT
  #define KMESSDEBUG_CONTACTEXTENSION
  #define KMESSDEBUG_CONTACTLIST
  #define KMESSDEBUG_GROUP
  #define KMESSDEBUG_GROUPLIST
  #define KMESSDEBUG_SETTINGSDIALOG
  #define KMESSDEBUG_CHATMASTER
  #define KMESSDEBUG_CHATWINDOW
  #define KMESSDEBUG_CHATVIEW
  #define KMESSDEBUG_CONTACTSIDEBAR
  #define KMESSDEBUG_CONTACTFRAME
  #define KMESSDEBUG_CONTACTACTION
  #define KMESSDEBUG_IDLETIMER
  #define KMESSDEBUG_POPUPNOTIFICATION
  #define KMESSDEBUG_CONTACTOFFLINENOTIFICATION
  #define KMESSDEBUG_CONTACTONLINENOTIFICATION
  #define KMESSDEBUG_EMAILNOTIFICATION
  #define KMESSDEBUG_CHATNOTIFICATION

  #define KMESSDEBUG_MIMEMESSAGE
  #define KMESSDEBUG_APPLICATION
  #define KMESSDEBUG_MIMEAPPLICATION
  #define KMESSDEBUG_P2PAPPLICATION
  #define KMESSDEBUG_FILETRANSFER_P2P
  #define KMESSDEBUG_PICTURETRANSFER_P2P
  #define KMESSDEBUG_FILETRANSFER
  #define KMESSDEBUG_REMOTEDESKTOP
  #define KMESSDEBUG_TRANSFERPROGRESS
  #define KMESSDEBUG_UPNP
  #define KMESSDEBUG_WEBAPPLICATION_P2P

  #define KMESSDEBUG_CONTACTPROPERTIES

#endif

#endif
